@@ -1,5 +1,13 @@
-import zope.i18nmessageid
+# -*- coding: latin-1 -*-
+# Copyright (c) 2008 gocept gmbh & co. kg
+# See also LICENSE.txt
+# $Id: db.py 6599 2008-09-12 11:31:37Z mac $
+
+import gocept.country.interfaces
 import pycountry
+import zope.i18nmessageid
+import zope.interface
+
 
 iso3166msg = zope.i18nmessageid.MessageFactory('iso3166')
 iso3166_2msg = zope.i18nmessageid.MessageFactory('iso3166_2')
@@ -35,6 +43,8 @@ class Data(object):
 class Country(Data):
     """Provides access to pycountry countries (ISO 3166)."""
 
+    zope.interface.implements(gocept.country.interfaces.ICountry)
+
     _msg = iso3166msg
 
     @property
